<?php
   if(!defined('ANTIBUG')) exit;
   
   require_once(LIB_PATH.'modules/ControlModule.php');
   
   class WebModule extends ControlModule
   {
      protected $renderData=array();
      protected $javascriptFiles=array();
      protected $cssFiles=array();
      public $page_title;
      public $proc_name;
      
      public function __construct()
      {
         global $COMMON_JAVASCRIPT_FILES, $COMMON_CSS_FILES;
         
         parent::__construct();
         
         // we load the default javascript files   
         $this->loadJavascriptFile($COMMON_JAVASCRIPT_FILES);
         $this->loadJavascriptFile($this->own->name); 
         
         // we load the default css files
         $this->loadCssFile($COMMON_CSS_FILES);
         $this->loadCssFile(str_replace('POP','',$this->own->name));       
      }
      
      public function main() {}
      
      /*
       * Assign an error to the render data.
       * This error will then be assign to smarty in SmartyView.php
       * @access  public
       * @param   string   $error   the error to display
       */
      public function setError($error)
      {
         $currentData=$this->session->renderData;
         if(is_array($currentData)) 
            $this->session->renderData=array_merge($currentData,array($error=>true));
         else
            $this->session->renderData=array($error=>true);
      }
      
      /*
       * Assign data to render with Smarty
       * @access  public
       * @param   string   $name name of the data to render
       * @param   mixed $data    to render
       */
      public function setRenderData($name, $data)
      {
         $this->renderData=array_merge($this->renderData, array($name=>$data));
      }
      
      /*
       * Return the data to be rendered in the template.
       * This is usefull for smarty, it can then assign this data into the template
       * @access  public
       * @return  array $data data to be rendered by smarty
       */
      public function getRenderData()
      {  
         $data=null;
         //data from module to be rendered
         if($this->renderData!==null)
            $data['moduleRender']=$this->renderData;
         else
            $data['moduleRender']=null;
         //data from session to be rendered  
         if($this->session->renderData!=false) {
            //data saved in session object to be rendered      
            $data['sessionRender']=$this->session->renderData;
            unset($this->session->renderData);
         }
         else
            $data['sessionRender']=null;
                        
         return $data;
      }
   
      /*
       * Return the list of css files to load in the template.
       * This is used by Smarty to add this list to the rest of the css files to assign
       * @access  public
       * @return  array $cssFiles   array containing the list of the extra css files to assign
       */
      public function getCssFiles()
      {
         return $this->cssFiles;
      }
      
      /*
       * Add a new css file to be load in smarty.
       * Also see WebModule::getCssFiles();
       * @access  public
       * @param1  string   $file_path  url to the css file to load
       * @param1  array $file_path  array containing a list of css files to load
       * @return  bool  true
       */
      public function loadCssFile($file_path)
      {
         if(is_array($file_path))
         {
            foreach($file_path as $file) {
               array_push($this->cssFiles,$file);
            }
         }
         else
            array_push($this->cssFiles,$file_path);
         
         return true;
      }
      
      /*
       * Return the list of javascript file to be load in smarty
       * This is used by SmartyView.php
       * @access  public
       * @return  array $javascriptFiles  an array containing the list of javascript files to assign
       */
      public function getJavascriptFiles()
      {
         return $this->javascriptFiles;
      }
      
      /*
       * Load a new javascript file or a array of javascript files to be load in the template
       * Also see WebModule::getJavascriptFiles()
       * @access  public
       * @param1  string   $file_path  the url to the javascript file to get assign in smarty
       * @param1  array $file_path  an array containing a list of url to be assign in smarty
       */
      public function loadJavascriptFile($file_path)
      {
         if(is_array($file_path))
         {
            foreach($file_path as $file)
            {
               array_push($this->javascriptFiles,$file);
            }
         }
         else
         {
            array_push($this->javascriptFiles,$file_path);
         }
         
         return true;
      }
   }
?>
