<?php
	if(!defined('ANTIBUG')) exit;
	
	require_once(PLOUF_PATH.'Database.php');
	
	/*
	 * Manages the HTTP headers
	 */
	class HTTPRequest
	{
		static private $instance=null;
			
		private function __construct()
		{
			Database::getInstance();
		}
		
		//singleton design pattern
		static public function getInstance()
		{
			if(self::$instance==null)
				self::$instance=new HTTPRequest();			
			
			return self::$instance;
		}
		
		/*
		 * Retrieves a variable in $_GET and $_POST
		 */
		public function getVar($varname,$method=false)
		{
			if($method==false) {
				if(isset($_GET[$varname]) && (!empty($_GET[$varname])) && is_string($_GET[$varname]))
					return 	$_GET[$varname];
				else
					return false;
			}
			else {
				if(isset($_POST[$varname]) && (!empty($_POST[$varname])) && is_string($_POST[$varname]))
					return 	$_POST[$varname];
				else
					return false;
			}
		}
		
		/*
		 * retrieves a variable (string) sent in a HTTP request
		 * and cleans it.
		 * 
		 * @param	string	$varname	the name of the variable to retrieve
		 * @param	string	[$method]	default=GET or POST
		 * 
		 * @return	string	$value		the value of the variable
		 * @return	bool	false		the variable does not exists
		 */
		public function getCleanString($varname,$method=false)
		{
			$value=$this->getVar($varname,$method);//retrieve the var
			//check if the variable exists
			if($value==false)
				return false;
				
			$value=utf8_encode($value);//XSS :)	
			$value=trim($value);
			$value=htmlentities($value);//XSS
			$value=mysql_real_escape_string($value);//SQL Injection
			
			return $value;			
		}
		
		/*
		 * retrieves an integer and cleans it.
		 * See previous function for more details.
		 */
		public function getCleanInteger($varname,$method=false)
		{
			$value=$this->getVar($varname,$method);
			$value=intval($value);
			return $value;
		}
		
		/*
		 * Redirect to a url
		 * @param	string	$url	url to redirect to
		 */
		public function redirect($url)
		{
			Header("Location: $url"); 
		}
		
		/*
		 * Return the ip address of the person
		 */
		public function getIPAddress()
		{	
			return mysql_real_escape_string($_SERVER['REMOTE_ADDR']);
		}
		
		/*
		 * Return the referrer of the person
		 */
		public function getHttpReferer()
		{
			if(isset($_SERVER['HTTP_REFERER']))
			{
				return mysql_real_escape_string($_SERVER['HTTP_REFERER']);
			}
			else
				return false;
		}
	}

?>
