<?php
   if(!defined('ANTIBUG')) exit;
   
   include_once(LIB_SMARTY.'Smarty.class.php');
   
   class InterfaceView extends Smarty
   {
      
      protected $module;
      
      public function __construct($module)
      {
         $this->Smarty();
         $this->module=$module;
         //configure smarty
         $this->template_dir=PATH_TEMPLATES;
         $this->compile_dir=PATH_TEMPLATES_COMPILED;
         
         //assigning global variables
         $this->assign('module_name', $this->module->own->name);
         $this->assign('proc_name', $this->module->proc_name);
         $this->assign('BROWSERRIDER_URL', BASE_URL);
      }

      /*
       * Assign a smarty variable to be used as the page title <title>{$pageTitle}</title>
       * @access  public
       * @param   string   $pageTitle  string to display as title
       */
      public function setPageTitle($pageTitle=null)
      {
         $this->assign('pagetitle',htmlentities($pageTitle));
      }
      
      /*
       * Add a stylesheet file to load in the template
       * @access  public
       * @param   string   $style   stylesheet url to load
       */
      public function addStyleSheet($style)
      {
         $styletag=array();
         if(is_array($style))
         {
            for($i=0;$i<count($style);$i++) {
                $styletag[$i]=PATH_CSS.$style[$i].'.css';            
            }
         } else {
            $styletag=PATH_CSS.$style.'.css';
         }
         
         $this->assign('stylesheets',$styletag);      
      }
      
      /*
       * Add a javascript file to load in the template
       * @access  public
       * @param   string   $js   javascript file url to load
       */
      public function addJavascriptFile($js)
      {
         $jstag=array();
         if(is_array($js))
         {
            for($i=0;$i<count($js);$i++)
            {
                $jstag[$i]=PATH_SCRIPTS.$js[$i].'.js';            
            }
         }
         else
         {
                  $jstag=$style.'.js';
         }
         
         $this->assign('javascript_files',$jstag);    
      }
      
      /*
       * Configure and display the template
       * @access  public
       */
      public function render()
      {
         // add some new assets
         $this->addStyleSheet($this->module->getCssFiles());
         $this->addJavascriptFile($this->module->getJavascriptFiles());
         // assign smarty variables to be used in the template
         $this->assignRenderData();
         $this->setPageTitle($this->module->page_title);
         // display the template
         $tplfile=$this->module->own->name.'.tpl';
         $this->display($tplfile);
      }
      
      /*
       * Assign module data to smarty variables
       * @access  private
       */
      private function assignRenderData()
      {
         // retrieve module data 
         $data=$this->module->getRenderData();
         $sessionRender=$data['sessionRender'];
         $moduleRender=$data['moduleRender'];
         // assign this data to the template
         if($data!=null) {
            if($moduleRender!==null) {
               foreach($moduleRender as $moduleVar=>$moduleValue) {
                  $this->assign($moduleVar, $moduleValue);
               }
            }
            if($sessionRender!==null) {
               foreach($sessionRender as $sessionVar=>$SessionValue) {
                  $this->assign($sessionVar,$SessionValue);          
               }
            }
         }  
      }
      
      /*
       * Configure and display the template OF A PAYLOAD
       * @access  public
       */
      public function renderPayloadTemplate()
      {
         //we change the template directory to the one for the payloads
         $this->template_dir=PAYLOADS_TEMPLATES;
         //assign data to render to the template
         $data=$this->module->getRenderData();
         if(!empty($data)) {
            foreach($data as $moduleVar=>$moduleValue) {
               $this->assign($moduleVar, $moduleValue);
            }
         }
         // display the template
         $tplfile=$this->module->own->name.'.tpl';
         $this->display($tplfile);
      }
      
      /*
       * Configure and display the template OF A PLUGIN
       * @access  public
       */
      public function renderPluginTemplate()
      {
         //we change the template directory to the one for the plugin
         $this->template_dir=PLUGINS_TEMPLATE;
         //assign data to render to the template
         $data=$this->module->getRenderData();
         if(!empty($data)) {
            foreach($data as $moduleVar=>$moduleValue) {
               $this->assign($moduleVar, $moduleValue);
            }
         }
         // display the template
         $tplfile=$this->module->own->name.'.tpl';
         $this->display($tplfile);
      }
   }
?>
